==> pcpartpicker-1.2.0-py3-none-any.whl: pcpartpicker/brands.py <==
brands = {'1MORE', '1STPLAYER', '3M', 'A4Tech', 'ABS', 'ACGAM', 'ADATA', 'AKG', 'AMD', 'AOC', 'APC', 'ARCTIC',
          'ASRock', 'ATI', 'AUKEY', 'AVM', 'AZIO', 'Acer', 'Achieva', 'Addlink', 'Adesso', 'Aerocool',
          'Akasa', 'Alienware', 'AllSmartLife', 'Alpenföhn', 'Alphacool', 'Altec Lansing', 'AmazonBasics', 'Anidees',
          'Anima', 'Anker', 'Antec', 'Aorus', 'Apacer', 'Apevia', 'Apex', 'Apotop', 'Apple', 'Apricom',
          'Archgon', 'Arctic Silver', 'Astro', 'Asus', 'Athena Power', 'Athenatech', 'Audeze', 'Audio-Technica', 'Audioengine',
          'Audiovox', 'Aula', 'Auria', 'AvP', 'Avantree', 'Avermedia', 'Avexir', 'Avid Technology',
          'Axiom', 'Azza', 'BFG', 'Behringer', 'Belkin', 'BenQ', 'Beyerdynamic', 'Biostar', 'BitFenix', 'Biwin',
          'BlueFinger', 'Bose', 'Broadway Com Corp', 'Buffalo Technology', 'Buslink', 'CFI', 'CHENBRO', 'CRYORIG',
          'CTA Digital', 'CTL', 'Cherry', 'Chester Creek Technologies', 'Chieftec', 'CiT', 'Cisco', 'Club',
          'Cobra', 'Coby', 'Colorful iGame', 'Compaq', 'Compustocx ', 'CoolMax', 'Cooler Master', 'Coolink',
          'Coollaboratory', 'Cooltek', 'Corsair', 'Cougar', 'Creative Labs', 'Crossover', 'Crucial',
          'Cubeternet', 'Cubitek', 'Cyber Acoustics', 'Cyber Snipa', 'CyberPower', 'Cyborg', 'Cyonic', 'D-Link',
          'DAN Cases', 'DIYPC', 'DLAND',
          'DSI', 'Das Keyboard', 'Deck', 'Deepcool', 'Dell', 'Delta Electronics', 'Denon', 'Diablotek',
          'Diamond', 'DoubleSight', 'Drevo', 'Ducky', 'Dynapower', 'Dynatron', 'E-Power', 'E-element', 'ECS',
          'EK', 'EVGA', 'EagleTec', 'Eaton', 'Edge Tech', 'Edifier', 'Edimax', 'Eizo', 'Element Gaming',
          'Eluktro', 'Eluktronics', 'Encore', 'Enermax', 'Enzotech', 'Epic Gear', 'Ergoguys',
          'Etekcity', 'Etymotic Research', 'Evercool', 'Evoluent', 'FNATIC', 'FSP Group', 'Favi', 'Feb Smart',
          'Feenix', 'Fellowes', 'Filco', 'FinalMouse', 'FirePower', 'Fluance', 'Fostex', 'Foxconn', 'Fractal Design',
          'Freecom', 'Fujitsu', 'Func', 'G-Technology', 'G.Skill', 'GALAX', 'GAMDIAS', 'GE', 'GMMK',
          'Gainward', 'Galaxy', 'Game Max', 'GamerChief', 'Gateway', 'GeIL', 'Gear Head', 'Gelid Solutions',
          'Genius', 'Gigabyte', 'Glorious PC Gaming Race', 'Gloway ', 'GranVela', 'Grandtec', 'Gyration', 'HAVIT',
          'HBT+', 'HEC', 'HG Computers', 'HIRALIY', 'HIS', 'HP', 'HT Omega', 'Hannspree', 'Happy Hacking',
          'Harman Kardon', 'Hawking Technology', 'Hcman', 'Hercules', 'HiFiMAN', 'HiVi', 'Hitachi',
          'Hyundai Technology', 'I/O Magic', 'IBM', 'ID-COOLING', 'IK Multimedia', 'IOGEAR', 'Iiyama',
          'Imation', 'Inamax', 'Ingram Micro', 'Inland', 'Inno3D', 'Innovation Cooling', 'Insignia', 'Intel',
          'Intenso', 'Interlink', 'Inwin', 'JBL', 'JMAX', 'JVC', 'Jaton', 'JayBird', 'Jeecoo',
          'Jelly Comb', 'Jetway', 'Jonsbo', 'KBParadise', 'KFA2', 'KOLINK', 'KRK', 'KUL', 'Kanto', 'Kensington',
          'Key Ovation', 'KeyScan', 'KeyTronic', 'Keycool', 'KingDian', 'Kingston', 'Kingwin', 'Klevv', 'Klipsch',
          'Koss', 'Kuroutoshikou', 'LC-Power', 'LDLC', 'LEPA', 'LG', 'LaCie', 'Labtec', 'Lamptron', 'Lazer3D',
          'Leadtek', 'Lenovo', 'Leopold', 'Lexar', 'Lian-Li', 'Linksys', 'Linkworld', 'Lite-On', 'Logisys',
          'Logitech', 'LyxPro', 'M-Audio', 'MS-Tech', 'MSI', 'Mackie', 'Mad Catz', 'Mars Gaming', 'Marshall',
          'Masscool', 'Max Keyboard', 'Maxtor', 'Memorex', 'Metallic Gear', 'Micca', 'Microlab', 'Micron',
          'Microsoft', 'Mionix', 'Mistel', 'Monoprice', 'Morex', 'Motorola', 'Mushkin',
          'MyDigitalSSD', 'NEC', 'NOX', 'NVIDIA', 'NZXT', 'Nanoxia', 'Naztech', 'Netgear', 'Nexus', 'Nidec Servo',
          'Ninox', 'Nixeus', 'NoFan', 'Noctua', 'NoiseBlocker', 'OCZ', 'OWC', 'OcUK', 'OLOy', 'Orico',
          'Ozone Gaming', 'PC Power & Cooling', 'PDP', 'PLDS', 'PNY', 'PPA International', 'Palit',
          'Panasonic', 'Panram', 'Pareema', 'Parvum Systems', 'Patriot', 'Penclic', 'Perixx', 'Phanteks', 'Philips',
          'Phononic', 'Pioneer', 'Pixio', 'Planar', 'Plantronics', 'Plextor', 'Plugable', 'Polaroid', 'Polk',
          'PowerColor', 'PowerSpec', 'Powertek', 'PreSonus', 'Prestige',
          'PrimoChill', 'Prolimatech', 'Pyle Audio', 'QLogic', 'QNAP', 'QNIX', 'Qisan', 'Qumax',
          'RAIJINTEK', 'RCA', 'RIOTORO', 'ROCCAT', 'Raidmax', 'Raptor Gaming', 'Raygo', 'Razer', 'Redragon', 'Reeven',
          'Replace Power', 'Rii', 'Rocketfish', 'Rosewill', 'Rottay', 'Rude Gamewear', 'SAMA', 'SHARKK',
          'SHARKOON', 'SIIG', 'SK hynix', 'SMK-Link', 'Sabrent', 'Sades', 'Sahara', 'Saitek', 'Sakar International',
          'Samsung', 'SanDisk', 'Sapphire', 'Satechi', 'Sceptre', 'Scythe',
          'SeaSonic', 'Seagate', 'Segotep', 'Seiki', 'Sennheiser', 'Sentey', 'Shure', 'Sigma', 'SilenX', 'SilentiumPC',
          'Silicon Power', 'Silverstone', 'SIVGA', 'Skullcandy', 'Smartaudios', 'Solid Gear', 'SolidTek', 'Sony',
          'SoundMAGIC',
          'Sparkle', 'Spartex', 'Speedlink', 'StarTech', 'Status Audio', 'SteelSeries', 'Streacom',
          'Sunbeam', 'Super Flower', 'Superlux', 'Supermicro', 'Super Talent', 'Swan Speakers', 'Swiftech',
          'Swiftpoint', 'Syba',
          'TAKSTAR', 'TCSunBow', 'TP-Link', 'TRENDnet', 'TUNIQ', 'Tacens', 'Takara Tomy', 'Targus', 'Teac', 'Team',
          'TeckNet', 'Tecware', 'Tek Republic', 'TekNmotion', 'Tesoro', 'Tex', 'Thermal Grizzly', 'Thermalright',
          'Thermaltake', 'Thermene', 'Thortech', 'Titan', 'Tomoko', 'Topower', 'Topre', 'Toshiba',
          'Tracer', 'Transcend', 'Tripp Lite', 'Trust', 'Turtle Beach', 'Ultra',
          'Unicomp', 'Unitech', 'UtechSmart', 'V-Color', 'V-MODA', 'V7',
          'VIOTEK', 'VIVO', 'Vantec', 'Varmilo', 'Velocifire', 'Verbatim', 'ViewEra', 'ViewSonic', 'VisionTek',
          'Vortex', 'WASD', 'Wacom', 'Wasabi Mango', 'Wesena', 'Western Digital', 'WinPower',
          'Wintec', 'Wooting', 'X2', 'XClio', 'XFX', 'XPG', 'Xigmatek', 'Xilence',
          'Xion', 'Xtrfy', 'Yamaha', 'Yamakasi', 'Yapster', 'Yate Loon', 'ZEROtherm', 'Zalman', 'Zelotes',
          'Zero Infinity', 'Ziotek', 'Zodiac', 'Zogis', 'Zotac', 'Zowie', 'be quiet!',
          'darkFlash', 'fenvi', 'i-rocks', 'iBuypower', 'iDeaUSA', 'iOne', 'iStarUSA', 'iZ3D', 'matias', 'mean:it',
          'nMEDIAPC'}

==> pcpartpicker-1.2.1-py3-none-any.whl: pcpartpicker/brands.py <==
brands = {'1MORE', '1STPLAYER', '3M', 'A4Tech', 'ABS', 'ACGAM', 'ADATA', 'AKG', 'AMD', 'AOC', 'APC', 'ARCTIC',
          'ASRock', 'ATI', 'AUKEY', 'AVM', 'AZIO', 'Acer', 'Achieva', 'Addlink', 'Adesso', 'Aerocool',
          'Akasa', 'Alienware', 'AllSmartLife', 'Alpenföhn', 'Alphacool', 'Altec Lansing', 'AmazonBasics', 'Anidees',
          'Anima', 'Anker', 'Antec', 'Aorus', 'Apacer', 'Apevia', 'Apex', 'Apotop', 'Apple', 'Apricom',
          'Archgon', 'Arctic Silver', 'Astro', 'Asus', 'Athena Power', 'Athenatech', 'Audeze', 'Audio-Technica', 'Audioengine',
          'Audiovox', 'Aula', 'Auria', 'AvP', 'Avantree', 'Avermedia', 'Avexir', 'Avid Technology',
          'Axiom', 'Azza', 'BFG', 'Behringer', 'Belkin', 'BenQ', 'Beyerdynamic', 'Biostar', 'BitFenix', 'Biwin',
          'BlueFinger', 'Bose', 'Broadway Com Corp', 'BrosTrend', 'Buffalo Technology', 'Buslink', 'CFI', 'CHENBRO', 'CRYORIG',
          'CTA Digital', 'CTL', 'Cherry', 'Chester Creek Technologies', 'Chieftec', 'CiT', 'Cisco', 'Club',
          'Cobra', 'Coby', 'Colorful iGame', 'Compaq', 'Compustocx ', 'CoolMax', 'Cooler Master', 'Coolink',
          'Coollaboratory', 'Cooltek', 'Corsair', 'Cougar', 'Creative Labs', 'Crossover', 'Crucial',
          'Cubeternet', 'Cubitek', 'Cyber Acoustics', 'Cyber Snipa', 'CyberPower', 'Cyborg', 'Cyonic', 'D-Link',
          'DAN Cases', 'DIYPC', 'DLAND',
          'DSI', 'Das Keyboard', 'Deck', 'Deepcool', 'Dell', 'Delta Electronics', 'Denon', 'Diablotek',
          'Diamond', 'DoubleSight', 'Drevo', 'Ducky', 'Dynapower', 'Dynatron', 'E-Power', 'E-element', 'ECS',
          'EK', 'EVGA', 'EagleTec', 'Eaton', 'Edge Tech', 'Edifier', 'Edimax', 'Eizo', 'Element Gaming',
          'Eluktro', 'Eluktronics', 'Encore', 'Enermax', 'Enzotech', 'Epic Gear', 'Ergoguys',
          'Etekcity', 'Etymotic Research', 'Evercool', 'Evoluent', 'FNATIC', 'FSP Group', 'Favi', 'Feb Smart',
          'Feenix', 'Fellowes', 'Filco', 'FinalMouse', 'FirePower', 'Fluance', 'Fostex', 'Foxconn', 'Fractal Design',
          'Freecom', 'Fujitsu', 'Func', 'G-Technology', 'G.Skill', 'GALAX', 'GAMDIAS', 'GE', 'GMMK',
          'Gainward', 'Galaxy', 'Game Max', 'GamerChief', 'Gateway', 'GeIL', 'Gear Head', 'Gelid Solutions',
          'Genius', 'Gigabyte', 'Glorious PC Gaming Race', 'Gloway ', 'GranVela', 'Grandtec', 'Gyration', 'HAVIT',
          'HBT+', 'HEC', 'HG Computers', 'HIRALIY', 'HIS', 'HP', 'HT Omega', 'Hannspree', 'Happy Hacking',
          'Harman Kardon', 'Hawking Technology', 'Hcman', 'Hercules', 'HiFiMAN', 'HiVi', 'Hitachi',
          'Hyundai Technology', 'I/O Magic', 'IBM', 'ID-COOLING', 'IK Multimedia', 'IOGEAR', 'Iiyama',
          'Imation', 'Inamax', 'Ingram Micro', 'Inland', 'Inno3D', 'Innovation Cooling', 'Insignia', 'Intel',
          'Intenso', 'Interlink', 'Inwin', 'JBL', 'JMAX', 'JVC', 'Jaton', 'JayBird', 'Jeecoo',
          'Jelly Comb', 'Jetway', 'Jonsbo', 'KBParadise', 'KFA2', 'KOLINK', 'KRK', 'KUL', 'Kanto', 'Kensington',
          'Key Ovation', 'KeyScan', 'KeyTronic', 'Keycool', 'KingDian', 'Kingston', 'Kingwin', 'Klevv', 'Klipsch',
          'Koss', 'Kuroutoshikou', 'LC-Power', 'LDLC', 'LEPA', 'LG', 'LaCie', 'Labtec', 'Lamptron', 'Lazer3D',
          'Leadtek', 'Lenovo', 'Leopold', 'Lexar', 'Lian-Li', 'Linksys', 'Linkworld', 'Lite-On', 'Logisys',
          'Logitech', 'LyxPro', 'M-Audio', 'MS-Tech', 'MSI', 'Mackie', 'Mad Catz', 'Mars Gaming', 'Marshall',
          'Masscool', 'Max Keyboard', 'Maxtor', 'Memorex', 'Metallic Gear', 'Micca', 'Microlab', 'Micron',
          'Microsoft', 'Mionix', 'Mistel', 'Monoprice', 'Morex', 'Motorola', 'Mushkin',
          'MyDigitalSSD', 'NEC', 'NOX', 'NVIDIA', 'NZXT', 'Nanoxia', 'Naztech', 'Netgear', 'Nexus', 'Nidec Servo',
          'Ninox', 'Nixeus', 'NoFan', 'Noctua', 'NoiseBlocker', 'OCZ', 'OWC', 'OcUK', 'OLOy', 'Orico',
          'Ozone Gaming', 'PC Power & Cooling', 'PDP', 'PLDS', 'PNY', 'PPA International', 'Palit',
          'Panasonic', 'Panram', 'Pareema', 'Parvum Systems', 'Patriot', 'Penclic', 'Perixx', 'Phanteks', 'Philips',
          'Phononic', 'Pioneer', 'Pixio', 'Planar', 'Plantronics', 'Plextor', 'Plugable', 'Polaroid', 'Polk',
          'PowerColor', 'PowerSpec', 'Powertek', 'PreSonus', 'Prestige',
          'PrimoChill', 'Prolimatech', 'Pyle Audio', 'QLogic', 'QNAP', 'QNIX', 'Qisan', 'Qumax',
          'RAIJINTEK', 'RCA', 'RIOTORO', 'ROCCAT', 'Raidmax', 'Raptor Gaming', 'Raygo', 'Razer', 'Redragon', 'Reeven',
          'Replace Power', 'Rii', 'Rocketfish', 'Rosewill', 'Rottay', 'Rude Gamewear', 'SAMA', 'SHARKK',
          'SHARKOON', 'SIIG', 'SK hynix', 'SMK-Link', 'Sabrent', 'Sades', 'Sahara', 'Saitek', 'Sakar International',
          'Samsung', 'SanDisk', 'Sapphire', 'Satechi', 'Sceptre', 'Scythe',
          'SeaSonic', 'Seagate', 'Segotep', 'Seiki', 'Sennheiser', 'Sentey', 'Shure', 'Sigma', 'SilenX', 'SilentiumPC',
          'Silicon Power', 'Silverstone', 'SIVGA', 'Skullcandy', 'Smartaudios', 'Solid Gear', 'SolidTek', 'Sony',
          'SoundMAGIC',
          'Sparkle', 'Spartex', 'Speedlink', 'StarTech', 'Status Audio', 'SteelSeries', 'Streacom',
          'Sunbeam', 'Super Flower', 'Superlux', 'Supermicro', 'Super Talent', 'Swan Speakers', 'Swiftech',
          'Swiftpoint', 'Syba',
          'TAKSTAR', 'TCSunBow', 'TP-Link', 'TRENDnet', 'TUNIQ', 'Tacens', 'Takara Tomy', 'Targus', 'Teac', 'Team',
          'TeckNet', 'Tecware', 'Tek Republic', 'TekNmotion', 'Tesoro', 'Tex', 'Thermal Grizzly', 'Thermalright',
          'Thermaltake', 'Thermene', 'Thortech', 'Titan', 'Tomoko', 'Topower', 'Topre', 'Toshiba',
          'Tracer', 'Transcend', 'Tripp Lite', 'Trust', 'Turtle Beach', 'Ultra',
          'Unicomp', 'Unitech', 'UtechSmart', 'V-Color', 'V-MODA', 'V7',
          'VIOTEK', 'VIVO', 'Vantec', 'Varmilo', 'Velocifire', 'Verbatim', 'ViewEra', 'ViewSonic', 'VisionTek',
          'Vortex', 'WASD', 'Wacom', 'Wasabi Mango', 'Wesena', 'Western Digital', 'WinPower',
          'Wintec', 'Wooting', 'X2', 'XClio', 'XFX', 'XPG', 'Xigmatek', 'Xilence',
          'Xion', 'Xtrfy', 'Yamaha', 'Yamakasi', 'Yapster', 'Yate Loon', 'ZEROtherm', 'Zalman', 'Zelotes',
          'Zero Infinity', 'Ziotek', 'Zodiac', 'Zogis', 'Zotac', 'Zowie', 'be quiet!',
          'darkFlash', 'fenvi', 'i-rocks', 'iBuypower', 'iDeaUSA', 'iOne', 'iStarUSA', 'iZ3D', 'matias', 'mean:it',
          'nMEDIAPC'}
